| Title: | The Scaled von Mises-Fisher Distribution |
|---|---|
| Description: | Functions to perform maximum likelihood estimation of and random value simulation from the scaled von Mises-Fisher distribution. The distribution is elliptical symmetric and can be applied to spherical and hyper-spherical data. The reference paper is Scealy J.L. and Wood A.T.A. (2019), <doi:10.1080/01621459.2019.1585249>. |
| Authors: | Michail Tsagris [aut, cre] |
| Maintainer: | Michail Tsagris <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0 |
| Built: | 2026-06-18 19:39:26 UTC |
| Source: | https://github.com/cran/svmf |
Functions to perform maximum likelihood estimation of and random value simulation from the scaled von Mises–Fisher distribution. For more information see Scealy and Wood (2019).
| Package: | svmf |
| Type: | Package |
| Version: | 1.0 |
| Date: | 2026-06-11 |
Michail Tsagris <[email protected]>.
Michail Tsagris [email protected]
Scealy J.L. and Wood A.T.A. (2019). Scaled von Mises-Fisher distributions and regression models for paleomagnetic directional data. Journal of the American Statistical Association, 114(528): 1547–1560.
Random value simulation from the scaled von Mises–Fisher distribution.
rsvmf(n, mu, a, kappa, Gamma = NULL)rsvmf(n, mu, a, kappa, Gamma = NULL)
n |
The sample size. |
mu |
The mean direction. |
a |
The vector of alphas. |
kappa |
The concentration parameter. |
Gamma |
The matrix with the |
A matrix with the simulated data.
Michail Tsagris.
R implementation and documentation: Michail Tsagris [email protected].
Scealy J.L. and Wood A.T.A. (2019). Scaled von Mises-Fisher distributions and regression models for paleomagnetic directional data. Journal of the American Statistical Association, 114(528): 1547–1560.
mu <- rnorm(3) mu <- mu / sqrt( sum(mu^2) ) a <- c(1, 3, 1/3) y <- rsvmf(1000, mu, a, 20) svmf.mle(y)mu <- rnorm(3) mu <- mu / sqrt( sum(mu^2) ) a <- c(1, 3, 1/3) y <- rsvmf(1000, mu, a, 20) svmf.mle(y)
Maximum likelihood estimation of the scaled von Mises–Fisher distribution.
svmf.mle(y, a1 = 1, maxit_outer = 100, maxit_V = 500, tol = 1e-6)svmf.mle(y, a1 = 1, maxit_outer = 100, maxit_V = 500, tol = 1e-6)
y |
A numerical matrix with the (hyper-)spherical observations. |
a1 |
The value of the |
maxit_outer |
The maximum number of iterations to perform. |
maxit_V |
The maximum number of iterations to perform to estimate the |
tol |
The tolerance value until convergence of the log-likelihood. |
A list including:
mu |
The estimated mean direction. |
kappa |
The estimated concentration parameter. |
a |
The estimated vector of alphas, the first value is 1, by default. |
loglik |
the log-likelihood value. |
Gamma |
The estimated matrix with the |
Michail Tsagris.
R implementation and documentation: Michail Tsagris [email protected].
Scealy J.L. and Wood A.T.A. (2019). Scaled von Mises-Fisher distributions and regression models for paleomagnetic directional data. Journal of the American Statistical Association, 114(528): 1547–1560.
mu <- rnorm(3) mu <- mu / sqrt( sum(mu^2) ) a <- c(1, 3, 1/3) y <- rsvmf(1000, mu, a, 20) svmf.mle(y)mu <- rnorm(3) mu <- mu / sqrt( sum(mu^2) ) a <- c(1, 3, 1/3) y <- rsvmf(1000, mu, a, 20) svmf.mle(y)